@@ -1,6 +1,6 @@
 #!/bin/env python
 
-# Copyright (c) 2014 Hewlett-Packard Development Company, L.P.
+# (C) Copyright 2014, 2015 Hewlett Packard Enterprise Development Company LP
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -61,6 +61,7 @@ class LibvirtCheck(AgentCheck):
             from novaclient.v1_1 import client
 
         id_cache = {}
+        flavor_cache = {}
         # Get a list of all instances from the Nova API
         nova_client = client.Client(self.init_config.get('admin_user'),
                                     self.init_config.get('admin_password'),
@@ -74,7 +75,11 @@ class LibvirtCheck(AgentCheck):
         for instance in instances:
             inst_name = instance.__getattr__('OS-EXT-SRV-ATTR:instance_name')
             inst_az = instance.__getattr__('OS-EXT-AZ:availability_zone')
-            inst_flavor = nova_client.flavors.get(instance.flavor['id'])
+            if instance.flavor['id'] in flavor_cache:
+                inst_flavor = flavor_cache[instance.flavor['id']]
+            else:
+                inst_flavor = nova_client.flavors.get(instance.flavor['id'])
+                flavor_cache[instance.flavor['id']] = inst_flavor
             id_cache[inst_name] = {'instance_uuid': instance.id,
                                    'hostname': instance.name,
                                    'zone': inst_az,
@@ -103,9 +108,9 @@ class LibvirtCheck(AgentCheck):
         return id_cache
 
     def _load_instance_cache(self):
-        """Load the cache if instance names to IDs.
+        """Load the cache map of instance names to Nova data.
 
-           If the cache does not yet exist, return an empty one.
+           If the cache does not yet exist or is damaged, (re-)build it.
         """
         instance_cache = {}
         try:
@@ -117,13 +122,22 @@ class LibvirtCheck(AgentCheck):
                     time_diff = time.time() - instance_cache['last_update']
                     if time_diff > self.init_config.get('nova_refresh'):
                         self._update_instance_cache()
-        except IOError:
-            # The file may not exist yet, and that's OK.  Build it now.
+        except (IOError, TypeError):
+            # The file may not exist yet, or is corrupt.  Rebuild it now.
+            self.log.warning("Instance cache missing or corrupt, rebuilding.")
             instance_cache = self._update_instance_cache()
             pass
 
         return instance_cache
 
+    def _is_cache_corrupt(self, cache):
+        """Verify that the cache contains a valid dictionary
+        """
+        if cache.__class__.__name__ != 'dict':
+            self.log.warning("Corrupt metrics cache detected.  Will rebuild.")
+            return True
+        return False
+
     def _load_metric_cache(self):
         """Load the counter metrics from the previous collection iteration
         """
@@ -131,8 +145,11 @@ class LibvirtCheck(AgentCheck):
         try:
             with open(self.metric_cache_file, 'r') as cache_yaml:
                 metric_cache = yaml.safe_load(cache_yaml)
+            if self._is_cache_corrupt(metric_cache):
+                metric_cache = {}
         except IOError:
             # The file may not exist yet.
+            metric_cache = {}
             pass
 
         return metric_cache
