@@ -37,6 +37,8 @@ class Network(checks.AgentCheck):
                 nic = nics[nic_name]
                 self.rate('net.in_bytes_sec', nic.bytes_recv, device_name=nic_name, dimensions=dimensions)
                 self.rate('net.out_bytes_sec', nic.bytes_sent, device_name=nic_name, dimensions=dimensions)
+                if instance.get('net_bytes_only'):
+                    continue
                 self.rate('net.in_packets_sec', nic.packets_recv, device_name=nic_name, dimensions=dimensions)
                 self.rate('net.out_packets_sec', nic.packets_sent, device_name=nic_name, dimensions=dimensions)
                 self.rate('net.in_errors_sec', nic.errin, device_name=nic_name, dimensions=dimensions)
